@@ -12,8 +12,8 @@ log = logging.getLogger(__name__)
 
 class SwidgetDimmer(SwidgetDevice):
 
-    def __init__(self, host,  secret_key: str, ssl: bool, use_websockets: bool) -> None:
-        super().__init__(host=host, secret_key=secret_key, ssl=ssl, use_websockets=use_websockets)
+    def __init__(self, host,  token_name: str, secret_key: str, ssl: bool, use_websockets: bool) -> None:
+        super().__init__(host=host, token_name=token_name, secret_key=secret_key, ssl=ssl, use_websockets=use_websockets)
         self._device_type = "dimmer"
 
     @property  # type: ignore
